@@ -5,8 +5,8 @@ use warnings;
 use base qw/Net::LDAP Class::Accessor::Fast/;
 use Carp qw/croak/;
 use Catalyst::Model::LDAP::Search;
-use Class::C3;
 use Data::Page;
+use MRO::Compat;
 use Net::LDAP::Constant qw/LDAP_CONTROL_VLVRESPONSE/;
 use Net::LDAP::Control::Sort;
 use Net::LDAP::Control::VLV;
